@@ -17,11 +17,14 @@ import noderenderer
 import imagedraw
 from metrics import AutoScaler
 from metrics import DiagramMetrics
-from imagedraw.filters.linejump import LineJumpDrawFilter
+from utils.collections import defaultdict
 
 
 class DiagramDraw(object):
     MetricsClass = DiagramMetrics
+    shadow_colors = defaultdict(lambda: (0, 0, 0))
+    shadow_colors['PNG'] = (64, 64, 64)
+    shadow_colors['PDF'] = (144, 144, 144)
 
     def __init__(self, format, diagram, filename=None, **kwargs):
         self.format = format.upper()
@@ -29,30 +32,26 @@ class DiagramDraw(object):
         self.fill = kwargs.get('fill', (0, 0, 0))
         self.badgeFill = kwargs.get('badgeFill', 'pink')
         self.filename = filename
-        self.scale_ratio = 1
+        self.shadow = self.shadow_colors[self.format.upper()]
 
-        basediagram = kwargs.get('basediagram', diagram)
-        self.metrics = self.MetricsClass(basediagram, format=format, **kwargs)
-
-        if self.format == 'PNG':
-            if kwargs.get('antialias'):
-                self.scale_ratio = ratio = 2
-                self.metrics = AutoScaler(self.metrics, scale_ratio=ratio)
-            self.shadow = kwargs.get('shadow', (64, 64, 64))
-        elif self.format == 'PDF':
-            self.shadow = kwargs.get('shadow', (144, 144, 144))
+        if self.format == 'PNG' and kwargs.get('antialias'):
+            self.scale_ratio = 2
         else:
-            self.shadow = kwargs.get('shadow', (0, 0, 0))
+            self.scale_ratio = 1
 
-        kwargs['scale_ratio'] = self.scale_ratio
-        drawer = imagedraw.create(self.format, self.filename, self.pagesize(),
-                                  shadow_style=diagram.shadow_style, **kwargs)
-        if drawer is None:
-            msg = 'failed to load %s image driver' % self.format
-            raise RuntimeError(msg)
+        self.drawer = imagedraw.create(self.format, self.filename,
+                                       filters=['linejump'],
+                                       scale_ratio=self.scale_ratio,
+                                       **kwargs)
 
-        self.drawer = LineJumpDrawFilter(drawer, self.metrics.cellsize / 2)
-        self.metrics.drawer = self.drawer
+        self.metrics = self.MetricsClass(kwargs.get('basediagram', diagram),
+                                         drawer=self.drawer, **kwargs)
+        if self.scale_ratio == 2:
+            self.metrics = AutoScaler(self.metrics,
+                                      scale_ratio=self.scale_ratio)
+
+        self.drawer.set_canvas_size(self.pagesize())
+        self.drawer.set_jump_radius(self.metrics.cellsize / 2)
 
     @property
     def nodes(self):
