@@ -15,22 +15,26 @@
 
 import re
 import sys
+import math
 from reportlab.pdfgen import canvas
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.ttfonts import TTFont
-from blockdiag.utils import textfolder, urlutil, Box
+from blockdiag.imagedraw import base, textfolder
+from blockdiag.imagedraw.utils import cached
+from blockdiag.utils import urlutil, Box, Size
 from blockdiag.utils.fontmap import parse_fontpath
 
 
-class PDFImageDraw(object):
-    self_generative_methods = []
-    nosideeffect_methods = ['textsize']
-
-    def __init__(self, filename, size, **kwargs):
-        self.canvas = canvas.Canvas(filename, pagesize=size)
-        self.size = size
+class PDFImageDraw(base.ImageDraw):
+    def __init__(self, filename, **kwargs):
+        self.filename = filename
+        self.canvas = None
         self.fonts = {}
 
+    def set_canvas_size(self, size):
+        self.canvas = canvas.Canvas(self.filename, pagesize=size)
+        self.size = size
+
     def set_font(self, font):
         if font.path is None:
             msg = "Could not detect fonts, use --font opiton\n"
@@ -124,11 +128,15 @@ class PDFImageDraw(object):
             maxwidth = 65535
 
         box = (0, 0, maxwidth, 65535)
-        textbox = textfolder.get(box, string, font, format='pdf',
-                                 adjustBaseline=True, canvas=self.canvas,
-                                 **kwargs)
+        textbox = textfolder.get(self, box, string, font,
+                                 adjustBaseline=True, **kwargs)
         return textbox.outlinebox.size
 
+    @cached
+    def textlinesize(self, string, font):
+        width = self.canvas.stringWidth(string, font.path, font.size)
+        return Size(int(math.ceil(width)), font.size)
+
     def text(self, xy, string, font, **kwargs):
         self.set_font(font)
         self.set_fill_color(kwargs.get('fill'))
@@ -152,9 +160,8 @@ class PDFImageDraw(object):
                 box = box.shift(x=-self.size.y, y=self.size.y)
 
         self.set_font(font)
-        lines = textfolder.get(box, string, font, format='pdf',
-                               adjustBaseline=True, canvas=self.canvas,
-                               **kwargs)
+        lines = textfolder.get(self, box, string, font,
+                               adjustBaseline=True, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
@@ -209,25 +216,27 @@ class PDFImageDraw(object):
         params = self.set_render_params(**kwargs)
         self.canvas.drawPath(pd, **params)
 
-    def loadImage(self, filename, box):
-        x = box[0]
-        y = self.size[1] - box[3]
-        w = box[2] - box[0]
-        h = box[3] - box[1]
-
-        if urlutil.isurl(filename):
+    def image(self, box, url):
+        if urlutil.isurl(url):
             from reportlab.lib.utils import ImageReader
             try:
-                filename = ImageReader(filename)
+                url = ImageReader(url)
             except:
                 msg = "WARNING: Could not retrieve: %s\n" % filename
                 sys.stderr.write(msg)
                 return
-        self.canvas.drawImage(filename, x, y, w, h, mask='auto',
-                              preserveAspectRatio=True)
+
+        y = self.size[1] - box[3]
+        self.canvas.drawImage(url, box.x1, y, box.width, box.height,
+                              mask='auto', preserveAspectRatio=True)
 
     def save(self, filename, size, format):
         # Ignore size and format parameter; compatibility for ImageDrawEx.
 
         self.canvas.showPage()
         self.canvas.save()
+
+
+def setup(self):
+    from blockdiag.imagedraw import install_imagedrawer
+    install_imagedrawer('pdf', PDFImageDraw)
