@@ -15,15 +15,17 @@
 
 import re
 import base64
-from blockdiag.utils import textfolder, urlutil, Box, XY
+from blockdiag.imagedraw import base as _base, textfolder
+from blockdiag.imagedraw.utils import cached
+from blockdiag.utils import urlutil, Box, XY
 from simplesvg import *
 
 feGaussianBlur = svgclass('feGaussianBlur')
 
 
-class SVGImageDrawElement(object):
+class SVGImageDrawElement(_base.ImageDraw):
     self_generative_methods = ['group', 'anchor']
-    nosideeffect_methods = ['textsize']
+    supported_path = True
 
     def __init__(self, svg, parent=None):
         self.svg = svg
@@ -101,10 +103,22 @@ class SVGImageDrawElement(object):
             maxwidth = 65535
 
         box = (0, 0, maxwidth, 65535)
-        textbox = textfolder.get(box, string, font,
-                                 ignore_pil=self.ignore_pil, **kwargs)
+        textbox = textfolder.get(self, box, string, font,
+                                 adjustBaseline=True, **kwargs)
         return textbox.outlinebox.size
 
+    @cached
+    def textlinesize(self, string, font, **kwargs):
+        if kwargs.get('ignore_pil', self.ignore_pil):
+            from blockdiag.imagedraw.utils import textsize
+            return textsize(string, font)
+        else:
+            if not hasattr(self, '_pil_drawer'):
+                import png
+                self._pil_drawer = png.ImageDrawEx(None)
+
+            return self._pil_drawer.textlinesize(string, font)
+
     def text(self, xy, string, font, **kwargs):
         fill = kwargs.get('fill')
 
@@ -140,8 +154,8 @@ class SVGImageDrawElement(object):
             elem.textarea(_box, string, font, **kwargs)
             return
 
-        lines = textfolder.get(box, string, font, adjustBaseline=True,
-                               ignore_pil=self.ignore_pil, **kwargs)
+        lines = textfolder.get(self, box, string, font,
+                               adjustBaseline=True, **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
@@ -232,19 +246,12 @@ class SVGImageDrawElement(object):
                      style=self.filter(filter))
         self.svg.addElement(pg)
 
-    def loadImage(self, filename, box):
-        if urlutil.isurl(filename):
-            url = filename
-        else:
-            string = open(filename, 'rb').read()
+    def image(self, box, url):
+        if not urlutil.isurl(url):
+            string = open(url, 'rb').read()
             url = "data:;base64," + base64.b64encode(string)
 
-        x = box[0]
-        y = box[1]
-        w = box[2] - box[0]
-        h = box[3] - box[1]
-
-        im = image(url, x, y, w, h)
+        im = image(url, box.x1, box.y1, box.width, box.height)
         self.svg.addElement(im)
 
     def anchor(self, url):
@@ -252,29 +259,33 @@ class SVGImageDrawElement(object):
         a_node.add_attribute('xlink:href', url)
         self.svg.addElement(a_node)
 
-        return SVGImageDrawElement(a_node)
+        return SVGImageDrawElement(a_node, self)
 
     def group(self):
         group = g()
         self.svg.addElement(group)
 
-        return SVGImageDrawElement(group)
+        return SVGImageDrawElement(group, self)
 
 
 class SVGImageDraw(SVGImageDrawElement):
-    def __init__(self, filename, size, **kwargs):
-        self.filename = filename
-        _svg = svg(0, 0, size[0], size[1], **kwargs)
-        super(SVGImageDraw, self).__init__(_svg)
-        self.ignore_pil = kwargs.get('ignore_pil')
+    def __init__(self, filename, **kwargs):
+        super(SVGImageDraw, self).__init__(None)
 
+        self.filename = filename
+        self.options = kwargs
+        self.ignore_pil = kwargs.get('ignore_pil')
+        self.set_canvas_size((0, 0))
+
+    def set_canvas_size(self, size):
+        self.svg = svg(0, 0, size[0], size[1], **self.options)
         uri = 'http://www.inkscape.org/namespaces/inkscape'
         self.svg.add_attribute('xmlns:inkspace', uri)
         uri = 'http://www.w3.org/1999/xlink'
         self.svg.add_attribute('xmlns:xlink', uri)
 
         # inkspace's Gaussian filter
-        if kwargs.get('style') != 'blur':
+        if self.options.get('style') != 'blur':
             fgb = feGaussianBlur(id='feGaussianBlur3780', stdDeviation=4.2)
             fgb.add_attribute('inkspace:collect', 'always')
             f = filter(-0.07875, -0.252, 1.1575, 1.504, id='filter_blur')
@@ -285,7 +296,7 @@ class SVGImageDraw(SVGImageDrawElement):
             self.svg.addElement(d)
 
         self.svg.addElement(title('blockdiag'))
-        self.svg.addElement(desc(kwargs.get('code')))
+        self.svg.addElement(desc(self.options.get('code')))
 
     def save(self, filename, size, format):
         # Ignore format parameter; compatibility for ImageDrawEx.
@@ -303,3 +314,8 @@ class SVGImageDraw(SVGImageDrawElement):
             open(self.filename, 'w').write(svg)
 
         return svg
+
+
+def setup(self):
+    from blockdiag.imagedraw import install_imagedrawer
+    install_imagedrawer('svg', SVGImageDraw)
