@@ -140,9 +140,7 @@ class DiagramMetrics(object):
     span_height = cellsize * 5
 
     def __init__(self, diagram, **kwargs):
-        self.drawer = None
-        self.format = kwargs.get('format')
-        self.ignore_pil = kwargs.get('ignore_pil')
+        self.drawer = kwargs.get('drawer')
 
         if diagram.node_width is not None:
             self.node_width = diagram.node_width
@@ -202,7 +200,7 @@ class DiagramMetrics(object):
         if self.drawer:
             return self.drawer.textsize(string, font, maxwidth=width)
         else:
-            from blockdiag.utils.textfolder.base import TextFolder
+            from blockdiag.imagedraw.textfolder.base import TextFolder
             folder = TextFolder((0, 0, width, 65535), string, font)
             return folder.outlinebox.size
 
