@@ -102,7 +102,7 @@ class NodeShape(object):
 
     def render_icon(self, drawer, **kwargs):
         if self.node.icon is not None and kwargs.get('shadow') is False:
-            drawer.loadImage(self.node.icon, self.iconbox)
+            drawer.image(self.iconbox, self.node.icon)
 
     def render_shape(self, drawer, format, **kwargs):
         pass
@@ -113,7 +113,8 @@ class NodeShape(object):
             drawer.textarea(self.textbox, self.node.label, font,
                             rotate=self.node.rotate,
                             fill=self.node.textcolor, halign=self.textalign,
-                            line_spacing=self.metrics.line_spacing)
+                            line_spacing=self.metrics.line_spacing,
+                            orientation=self.node.label_orientation)
 
     def render_number_badge(self, drawer, **kwargs):
         if self.node.numbered is not None and kwargs.get('shadow') is None:
@@ -122,7 +123,7 @@ class NodeShape(object):
             xy = self.metrics.cell(self.node).topleft
             r = self.metrics.cellsize * 3 / 2
 
-            box = (xy.x - r, xy.y - r, xy.x + r, xy.y + r)
+            box = Box(xy.x - r, xy.y - r, xy.x + r, xy.y + r)
             font = self.metrics.font_for(self.node)
             drawer.ellipse(box, outline=self.node.linecolor, fill=badgeFill)
             drawer.textarea(box, self.node.numbered, font,
