@@ -31,7 +31,7 @@ class Circle(NodeShape):
         elif self.node.background:
             drawer.ellipse(self.textbox, fill=self.node.color,
                            outline=self.node.color)
-            drawer.loadImage(self.node.background, self.textbox)
+            drawer.image(self.textbox, self.node.background)
             drawer.ellipse(self.textbox, fill="none",
                            outline=self.node.linecolor, style=self.node.style)
         else:
