@@ -41,7 +41,7 @@ class Ellipse(NodeShape):
         elif self.node.background:
             drawer.ellipse(box, fill=self.node.color,
                            outline=self.node.color)
-            drawer.loadImage(self.node.background, self.textbox)
+            drawer.image(self.textbox, self.node.background)
             drawer.ellipse(box, fill="none",
                            outline=self.node.linecolor, style=self.node.style)
         else:
