@@ -51,7 +51,7 @@ class Input(NodeShape):
         elif self.node.background:
             drawer.polygon(shape, fill=self.node.color,
                            outline=self.node.color)
-            drawer.loadImage(self.node.background, self.textbox)
+            drawer.image(self.textbox, self.node.background)
             drawer.polygon(shape, fill="none",
                            outline=self.node.linecolor, style=self.node.style)
         else:
