@@ -25,10 +25,15 @@ from blockdiag.drawer import DiagramDraw
 from blockdiag.utils.collections import namedtuple
 
 
-format = 'PNG'
-antialias = False
-fontpath = None
-outputdir = None
+directive_options_default = dict(format='PNG',
+                                 antialias=False,
+                                 fontpath=None,
+                                 outputdir=None,
+                                 nodoctype=False,
+                                 noviewbox=False,
+                                 inline_svg=False,
+                                 ignore_pil=False)
+directive_options = {}
 
 
 def relfn2path(env, filename):
@@ -148,6 +153,10 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
 
         return results
 
+    @property
+    def global_options(self):
+        return directive_options
+
     def node2diagram(self, node):
         tree = parser.parse_string(node['code'])
         return ScreenNodeBuilder.build(tree)
@@ -155,12 +164,21 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
     def node2image(self, node, diagram):
         filename = self.image_filename(node)
         fontpath = self.detectfont()
-        drawer = DiagramDraw(format, diagram, filename,
-                             font=fontpath, antialias=antialias)
+        format = self.global_options['format'].lower()
 
-        if not os.path.isfile(filename):
+        if format == 'svg' and self.global_options['inline_svg'] is True:
+            filename = None
+
+        kwargs = dict(self.global_options)
+        del kwargs['format']
+        drawer = DiagramDraw(format, diagram, filename, **kwargs)
+
+        if filename is None or not os.path.isfile(filename):
             drawer.draw()
-            drawer.save()
+            content = drawer.save()
+
+            if format == 'svg' and self.global_options['inline_svg'] is True:
+                return nodes.raw('', content.decode('utf-8'), format='html')
 
         size = drawer.pagesize()
         options = node['options']
@@ -185,6 +203,7 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
 
     def detectfont(self):
         Options = namedtuple('Options', 'font')
+        fontpath = self.global_options['fontpath']
         if isinstance(fontpath, (list, tuple)):
             options = Options(fontpath)
         elif isinstance(fontpath, (str, unicode)):
@@ -203,10 +222,13 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
             sha = sha
 
         options = dict(node['options'])
-        options.update(font=fontpath, antialias=antialias)
+        options.update(font=self.global_options['fontpath'],
+                       antialias=self.global_options['antialias'])
         hashseed = node['code'].encode('utf-8') + str(options)
         hashed = sha(hashseed).hexdigest()
 
+        format = self.global_options['format']
+        outputdir = self.global_options['outputdir']
         filename = "%s%s-%s.%s" % (self.name, prefix, hashed, format.lower())
         if outputdir:
             filename = os.path.join(outputdir, filename)
@@ -285,6 +307,8 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
             row = nodes.row()
             for attr in desc:
                 entry = nodes.entry()
+                if not isinstance(attr, (str, unicode)):
+                    attr = str(attr)
                 self.state.nested_parse(ViewList([attr], source=attr),
                                         0, entry)
                 row += entry
@@ -295,10 +319,9 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
 
 
 def setup(**kwargs):
-    global format, antialias, fontpath, outputdir
-    format = kwargs.get('format', 'PNG')
-    antialias = kwargs.get('antialias', False)
-    fontpath = kwargs.get('fontpath', None)
-    outputdir = kwargs.get('outputdir', None)
+    global directive_options, directive_options_default
+
+    for key, value in directive_options_default.items():
+        directive_options[key] = kwargs.get(key, value)
 
     rst.directives.register_directive("blockdiag", BlockdiagDirective)
